=======
HISTORY
=======

========================
1.1.1 (20 October, 2016)
========================
* improved unit testing to include each individual function, as well as
comparing the calculated FishTaco output to a pre-computed example output
* removed debugging statements from code
* added documentation to all functions
* resolved several runtime warnings for edge cases

=========================
1.1.0 (18 February, 2016)
=========================
* added the option to run FishTaco with no functional profile input,
predicting it from the taxonomic profiles and genomic content inputs
* added a unit test for the option to run with no functional profiles input
* added the option to run FishTaco on only a subset of functions by
supplying a list file as input

=====================
1.0.5 (15 July, 2015)
=====================
* Initial release

